Index: /trunk/src/VBox/VMM/HWACCM.cpp
===================================================================
--- /trunk/src/VBox/VMM/HWACCM.cpp	(revision 13174)
+++ /trunk/src/VBox/VMM/HWACCM.cpp	(revision 13175)
@@ -602,9 +602,9 @@
              * real and protected mode without paging with EPT.
              */
-            pVM->hwaccm.s.vmx.pRealModeEPTPageTable = (PX86PD)((char *)pVM->hwaccm.s.vmx.pRealModeTSS + PAGE_SIZE * 3);
+            pVM->hwaccm.s.vmx.pNonPagingModeEPTPageTable = (PX86PD)((char *)pVM->hwaccm.s.vmx.pRealModeTSS + PAGE_SIZE * 3);
             for (unsigned i=0;i<X86_PG_ENTRIES;i++)
             {
-                pVM->hwaccm.s.vmx.pRealModeEPTPageTable->a[i].u = X86_PDE4M_P | X86_PDE4M_RW | X86_PDE4M_US | X86_PDE4M_A | X86_PDE4M_D | X86_PDE4M_PS | X86_PDE4M_G;
-                pVM->hwaccm.s.vmx.pRealModeEPTPageTable->a[i].b.u10PageNo  = _4M * i;
+                pVM->hwaccm.s.vmx.pNonPagingModeEPTPageTable->a[i].u = X86_PDE4M_P | X86_PDE4M_RW | X86_PDE4M_US | X86_PDE4M_A | X86_PDE4M_D | X86_PDE4M_PS | X86_PDE4M_G;
+                pVM->hwaccm.s.vmx.pNonPagingModeEPTPageTable->a[i].b.u10PageNo  = _4M * i;
             }
 
@@ -614,7 +614,7 @@
             LogRel(("HWACCM: Real Mode TSS guest physaddr  = %VGp\n", GCPhys));
 
-            rc = PDMVMMDevHeapR3ToGCPhys(pVM, pVM->hwaccm.s.vmx.pRealModeEPTPageTable, &GCPhys);
+            rc = PDMVMMDevHeapR3ToGCPhys(pVM, pVM->hwaccm.s.vmx.pNonPagingModeEPTPageTable, &GCPhys);
             AssertRC(rc);            
-            LogRel(("HWACCM: Real Mode EPT CR3             = %VGp\n", GCPhys));
+            LogRel(("HWACCM: Non-Paging Mode EPT CR3       = %VGp\n", GCPhys));
 
             rc = SUPCallVMMR0Ex(pVM->pVMR0, VMMR0_DO_HWACC_SETUP_VM, 0, NULL);
Index: /trunk/src/VBox/VMM/VMMR0/HWVMXR0.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMR0/HWVMXR0.cpp	(revision 13174)
+++ /trunk/src/VBox/VMM/VMMR0/HWVMXR0.cpp	(revision 13175)
@@ -1212,5 +1212,5 @@
 
                 /* We convert it here every time as pci regions could be reconfigured. */
-                rc = PDMVMMDevHeapR3ToGCPhys(pVM, pVM->hwaccm.s.vmx.pRealModeEPTPageTable, &GCPhys);
+                rc = PDMVMMDevHeapR3ToGCPhys(pVM, pVM->hwaccm.s.vmx.pNonPagingModeEPTPageTable, &GCPhys);
                 AssertRC(rc);
 

Index: /trunk/src/VBox/VMM/HWACCMInternal.h
===================================================================
--- /trunk/src/VBox/VMM/HWACCMInternal.h	(revision 13174)
+++ /trunk/src/VBox/VMM/HWACCMInternal.h	(revision 13175)
@@ -240,6 +240,6 @@
         R3PTRTYPE(PVBOXTSS)         pRealModeTSS;
 
-        /** Virtual address of the identity page table used for real mode emulation in EPT mode. */
-        R3PTRTYPE(PX86PD)           pRealModeEPTPageTable;
+        /** Virtual address of the identity page table used for real mode and protected mode without paging emulation in EPT mode. */
+        R3PTRTYPE(PX86PD)           pNonPagingModeEPTPageTable;
 
         /** R0 memory object for the virtual APIC mmio cache. */